Category styles
===============

Misago categories allow you to specify their css class when editing them in admin control panel.

This class is then used to build proper css class names used around the UI. For example, entering "protoss" in class's css name will result in category on categories lists and threads in this class on threads list having `list-group-item-category-protoss` css class on them, allowing you to differentiate this category and its threads on lists. In addition to this, such category's page and its thread page would have `page-protoss` class so you could customize it further.


## Default classes

Misago's default theme defines following basic classes, visualised as color bands added to left side of category and its threads on lists:

- `primary`
- `info`
- `success`
- `danger`
- `warning`
- `inversed`
